@@ -24,6 +24,7 @@ from web_foundation.kernel.container import GenericDependencyContainer
 from web_foundation.kernel.messaging.dispatcher import IDispatcher, IDispatcherIsolate
 from web_foundation.kernel.isolate import Isolate
 from web_foundation import settings
+from web_foundation.settings_event import SettingsChangeEvent
 
 
 class App(Generic[GenericDependencyContainer]):
@@ -163,6 +164,10 @@ class App(Generic[GenericDependencyContainer]):
         self.sanic.before_server_start(reg_metrics)
 
         async def listen_channel(s_app: Sanic):
+            async def on_settings_change(event: SettingsChangeEvent):
+                setattr(settings, event.name, event.value)
+
+            s_app.ctx.channel.add_event_listener(SettingsChangeEvent, on_settings_change)
             # noinspection PyAsyncCall
             s_app.add_task(s_app.ctx.channel.listen_consume())
 
