@@ -1,6 +1,7 @@
 import asyncio
 import signal
 from abc import ABCMeta
+from asyncio import CancelledError
 from typing import Dict, Generic
 
 import loguru
@@ -29,11 +30,15 @@ class Isolate(Generic[GenericDependencyContainer], metaclass=ABCMeta):
 
     def run_forked(self) -> None:
         async def call():
-            nonlocal self
-            await self.container.init_resources()
-            asyncio.create_task(self.channel.listen_consume())
-            await self.work(**self.init_kwargs)
-            await self.container.shutdown_resources()
+            try:
+                nonlocal self
+                await self.container.init_resources()
+                asyncio.create_task(self.channel.listen_consume())
+                await self.work(**self.init_kwargs)
+                await self.container.shutdown_resources()
+            except CancelledError:
+                await self.container.shutdown_resources()
+                self.close()
 
         def signal_handler(sig, frame):
             for task in asyncio.all_tasks():
